<TS version="2.1" language="ur">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">پتہ یا لیبل کی تصیح کیلیئے داہنا کلک</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>نیا پتہ تخلیق کریں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;نیا</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>موجودہ چنے ہوئے پتے کو نقل کریں سسٹم کلپ بورڈ پر</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">نقل</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">بند</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سلیکٹڈ پتے کو مٹائیں</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">پتہ یا لیبل تلاشی کے لئے درج کریں</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>موجودہ ڈیٹا کو فائیل میں محفوظ کریں</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹا</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">چننا</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">پتے ارسال کیے جارہے ہیں</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">پتے موصول ہورہے ہیں</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">یہ آپ کے ادائیگی بھیجنے کے لئے بٹ کوائن ایڈریس ہیں.سکے بھیجنے سے پہلے ہمیشہ رقم اور وصول کنندہ پتہ چیک کریں۔</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">ادائیگیوں کے لئے آپ کے بٹ کوائن ایڈریس ہیں۔ نئے پتے بنانے کے لئے وصول کنندہ ٹیب میں 'نیا وصول کنندہ پتہ بنائیں' بٹن کا استعمال کریں۔دستخط صرف 'میراثی' قسم کے پتے کے ساتھ ہی ممکن ہے۔</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;پتا نقل کریں</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">&amp;لیبل نقل کریں</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;تدوین</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">پتا فہرست ایکسپورٹ کریں</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See https://en.wikipedia.org/wiki/Comma-separated_values</extracomment>
        <translation type="unfinished">کوما سے الگ فائل</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">پتا فہرست محفوظ کرتے ہوئے %1 نقص کا سامنا ہوا۔ دوبارہ کوشش کریں۔</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">ایکسپورٹ ناکام ہوا</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">لیبل</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">پتہ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(کوئی لیبل نہیں)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>پاسفریج ڈائیلاگ</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">پاسفریز دکھائیں</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">بٹوے کو خفیہ کریں</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">پرس کو غیر مقفل کرنے کے لئے اس آپریشن کو آپ کے بٹوے کا پاسفریز درکار ہے۔</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">بستہ کھولیں</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">پاسفریز تبدیل کریں</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">پرس کی خفیہ کاری کی تصدیق کریں</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">انتباہ: اگر آپ اپنا بٹوہ انکرپٹ کرتے ہیں اور اپنا پاس فریز کھو دیتے ہیں تو ، آپ اپنے تمام بٹکوئنز کھو دیں گے.</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">کیا آپ واقعی اپنے بٹوے کو خفیہ کرنا چاہتے ہیں؟</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">بٹوے کو خفیہ کردہ</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">پرس کے لئے نیا پاسفریج درج کریں۔ براہ کرم دس یا زیادہ بے ترتیب حرفوں ، یا آٹھ یا زیادہ الفاظ کا پاس فریز استعمال کریں۔</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">پرس کے لئے پرانا پاسفریج اور نیا پاسفریز درج کریں۔</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">یاد رکھیں کہ آپ کے پرس کو خفیہ کرنا آپ کے بٹ کوائنز کو میلویئر/چور سے آپ کے کمپیوٹر میں انفیکشن لگانے کے ذریعہ چوری ہونے سے پوری طرح محفوظ نہیں رکھ سکتا ہے۔</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">بٹوے کو خفیہ کرنا ہے</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">آپ کا پرس خفیہ ہونے والا ہے۔</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">آپ کا پرس اب خفیہ ہے۔</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">اہم: کسی بھی پچھلے بیک اپ کو جو آپ نے اپنی بٹوے فائل سے بنایا ہے اس کی جگہ نئی تیار کردہ ، خفیہ کردہ والیٹ فائل کی جگہ لینا چاہئے۔ سیکیورٹی وجوہات کی بناء پر ، بغیر خفیہ کردہ والیٹ فائل کا پچھلا بیک اپ بیکار ہوجائے گا جیسے ہی آپ نیا ، خفیہ کردہ پرس استعمال کرنا شروع کردیں گے۔</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">والیٹ کی خفیہ کاری ناکام ہوگئی</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">اندرونی خامی کے سبب والیٹ کی خفیہ کاری ناکام ہوگئی۔ آپ کا پرس خفیہ نہیں ہوا تھا۔</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">فراہم کردہ پاسفریز مماثل نہیں ہیں۔</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">والیٹ انلاک ناکام ہوگیا</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">بٹوے کی ڈکرپشن کے لئے درج کردہ پاس فریس غلط تھا۔</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">والیٹ کا پاسفریز کامیابی کے ساتھ تبدیل کردیا گیا تھا۔</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">انتباہ: کیپس لاک کی آن ہے!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">آئی پی / نیٹ ماسک</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">تک پابندی عائد</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">بھگوڑے رعایت</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">ایک مہلک خرابی واقع ہوئی ہے۔  %1 اب مزید سلامتی سے جاری نہیں رہ سکتا ہے اور چھوڑ دے گا۔</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">داخلی خامی</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">ایک داخلی خامی پیش آگئی۔ %1 محفوظ طریقے سے جاری رکھنے کی کوشش کریں گے۔ یہ ایک غیر متوقع مسئلہ ہے جس کی اطلاع ذیل میں دی جاسکتی ہے۔</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: Specified data directory "%1" does not exist.</source>
        <translation type="unfinished">خرابی: مخصوص ڈیٹا ڈائریکٹری ""  %1 موجود نہیں ہے۔</translation>
    </message>
    <message>
        <source>Error: Cannot parse configuration file: %1.</source>
        <translation type="unfinished">خرابی: کنفگریشن فائل کا تجزیہ نہیں کیا جاسکتا۔%1.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">خرابی:%1</translation>
    </message>
    <message>
        <source>Error initializing settings: %1</source>
        <translation type="unfinished">ترتیبات کو شروع کرنے میں خرابی:%1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1ابھی تک سلامتی سے باہر نہیں نکلا…</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">رقم</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>اور جائزہ</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>پرس کا عمومی جائزہ دکھائیں</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>اور لین دین</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>ٹرانزیکشن ہسٹری کو براؤز کریں</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>باہر نکلیں</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>درخواست چھوڑ دیں</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;معلومات%1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">%1 کے بارے میں معلومات دکھایں</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>کے بارے میں &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Qt کے بارے میں معلومات دکھائیں</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">%1 اختیارات کے لئےترتیب ترمیم کریں</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">ایک نیا پرس بنائیں</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">پرس:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">نیٹ ورک کی سرگرمی غیر فعال ہے۔</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">پراکسی &lt;b&gt;فعال&lt;/b&gt; ہے:%1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>بٹ کوائن ایڈریس پر سکے بھیجیں</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>کسی دوسرے مقام پر بیک اپ والیٹ</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>بٹوے کی خفیہ کاری کے لئے استعمال ہونے والا پاسفریز تبدیل کریں</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;بھیجیں</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;وصول کریں</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;اختیارات…</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;دکھانا چھپانا</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>مین ونڈو دکھائیں یا چھپائیں</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp; والیٹ کو خفیہ کریں…</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp; بیک اپ والیٹ…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp; بیک اپ والیٹ…</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">سائن اور پیغام…</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>اپنے ویکیپیڈیا پتوں کے ساتھ پیغامات پر دستخط کریں تاکہ آپ ان کے مالک ہوں</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">پیغام کی توثیق کریں…</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>پیغامات کی توثیق کریں تاکہ یہ یقینی بن سکے کہ ان پر بٹ کوائن کے مخصوص پتوں پر دستخط ہوئے ہیں</translation>
    </message>
    <message>
        <source>Load PSBT from clipboard…</source>
        <translation type="unfinished">کلپ بورڈ سے پی ایس بی ٹی لوڈ کریں…</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">کھولیں اور یو آر آئی…</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">پرس بند کریں…</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">خرابی:%1</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">رقم:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">تاریخ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(کوئی لیبل نہیں)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>پتہ</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">نقص</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">پتہ</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">رقم:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">پرس:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">کاپی پتہ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">تاریخ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">لیبل</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(کوئی لیبل نہیں)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation type="unfinished">ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">رقم:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>بیلنس:</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(کوئی لیبل نہیں)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">تاریخ</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">رقم</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">تاریخ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">لیبل</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(کوئی لیبل نہیں)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See https://en.wikipedia.org/wiki/Comma-separated_values</extracomment>
        <translation type="unfinished">کوما سے الگ فائل</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">تاریخ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">لیبل</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">پتہ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">ایکسپورٹ ناکام ہوا</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">ایک نیا پرس بنائیں</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">برآمد</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">موجودہ ڈیٹا کو فائیل میں محفوظ کریں</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">نقص</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">ناکافی فنڈز</translation>
    </message>
    </context>
</TS>